#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_SUCCESSOR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_SUCCESSOR_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/scalar/successor.hpp>

#endif
